@@ -3,6 +3,8 @@ Make a query into the store to find some
 tiddlers and list them in the interface.
 """
 
+import logging
+
 import urllib
 
 from tiddlyweb import control
@@ -14,6 +16,24 @@ from tiddlyweb.web import util as web
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 
 
+def get_search_query(environ):
+    try:
+        search_query = environ['tiddlyweb.query']['q'][0]
+        search_query = urllib.unquote(search_query)
+    except (KeyError, IndexError):
+        raise HTTP400('query string required')
+    return search_query
+
+def get_tiddlers(environ):
+    search_query = get_search_query(environ)
+    store = environ['tiddlyweb.store']
+    try:
+        tiddlers = store.search(search_query)
+        logging.debug('got search results from store')
+    except StoreMethodNotImplemented:
+        raise HTTP400('Search system not implemented')
+    return tiddlers
+
 def get(environ, start_response):
     """
     Perform a search on the store. What search
@@ -21,25 +41,14 @@ def get(environ, start_response):
     on the search implementation (if any) in the
     chosen store.
     """
-    try:
-        search_query = environ['tiddlyweb.query']['q'][0]
-        search_query = urllib.unquote(search_query)
-    except (KeyError, IndexError):
-        raise HTTP400('query string required')
 
     filters = environ['tiddlyweb.filters']
-
     store = environ['tiddlyweb.store']
-    try:
-        tiddlers = store.search(search_query)
-    except StoreMethodNotImplemented:
-        raise HTTP400('Search system not implemented')
+
+    tiddlers = get_tiddlers(environ)
 
     usersign = environ['tiddlyweb.usersign']
 
-# It's necessary to get the tiddler off the store
-# in case we are doing wiki or atom outputs of the
-# search.
     tmp_bag = Bag('tmp_bag', tmpbag=True, searchbag=True)
     bag_readable = {}
 
